@@ -1,12 +1,14 @@
 import os
+from typing import List
 from PIL import Image
 import requests
 # local imports
 import pycurtain.secrete.stuff as shh
 from pycurtain.utility.image import pil_img_to_byte_array, download_img
+from pycurtain.source.protos.image import TaskImage
 
 
-class DeepAI():
+class DeepAI(TaskImage):
 
     def __init__(self, api_key: str = None):
 
@@ -19,7 +21,7 @@ class DeepAI():
                     "DEEP AI API KEY environment variable not found")
 
     # takes image and returns upsampled image
-    def upscale(self, img_i: Image.Image) -> Image.Image:
+    def upscale(self, img_i: Image.Image) -> List[Image.Image]:
 
         if img_i is None:
             raise Exception("img_i is None")
@@ -48,5 +50,5 @@ class DeepAI():
         # download the image from the response
         img_o = download_img(url)
 
-        # return the image
-        return img_o
+        # wrap image in list
+        return [img_o]
